var group__group_datatypes =
[
    [ "integral_constant", "structboost_1_1hana_1_1integral__constant.html", [
      [ "integral_c", "structboost_1_1hana_1_1integral__constant.html#a8e52c0f4a65a852dc88f97259a05ff17", null ],
      [ "operator+", "structboost_1_1hana_1_1integral__constant.html#a897cb2a15eeef6924a2b2fda36eac874", null ],
      [ "operator-", "structboost_1_1hana_1_1integral__constant.html#a7217b8e64dd43d969faca2c727db08b3", null ],
      [ "operator-", "structboost_1_1hana_1_1integral__constant.html#a8a38703ec26537f474a9f0a5953ac582", null ],
      [ "operator*", "structboost_1_1hana_1_1integral__constant.html#a1495dcab0ecb2627ce1e834afe98f8d6", null ],
      [ "operator/", "structboost_1_1hana_1_1integral__constant.html#a7191ce0909ad60058d4fbf8f1d3ef235", null ],
      [ "operator%", "structboost_1_1hana_1_1integral__constant.html#abae3f5f4393987734db5b7a638735918", null ],
      [ "operator==", "structboost_1_1hana_1_1integral__constant.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
      [ "operator!=", "structboost_1_1hana_1_1integral__constant.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
      [ "operator||", "structboost_1_1hana_1_1integral__constant.html#acac20f8a52750bae122668729ec4df36", null ],
      [ "operator&&", "structboost_1_1hana_1_1integral__constant.html#a69ba502677100036ab9e7101e91ca28f", null ],
      [ "operator!", "structboost_1_1hana_1_1integral__constant.html#a8edb19203d27b84512479602eeeb8fe3", null ],
      [ "operator<", "structboost_1_1hana_1_1integral__constant.html#aca31ad50b2d35d48aac88aa762530c75", null ],
      [ "operator>", "structboost_1_1hana_1_1integral__constant.html#a65b9400772e651101ae83d7f9f7ba84d", null ],
      [ "operator<=", "structboost_1_1hana_1_1integral__constant.html#a971bac762b767fe0ec222adb367c9aeb", null ],
      [ "operator>=", "structboost_1_1hana_1_1integral__constant.html#adec95a8109b858673412671ba341611b", null ],
      [ "operator\"\"_c", "structboost_1_1hana_1_1integral__constant.html#a1c078fd00db48686ca9e0aa17f47344e", null ]
    ] ],
    [ "basic_tuple", "structboost_1_1hana_1_1basic__tuple.html", [
      [ "make< basic_tuple_tag >", "structboost_1_1hana_1_1basic__tuple.html#a53975be786ae1db16185edab229547cd", null ],
      [ "make_basic_tuple", "structboost_1_1hana_1_1basic__tuple.html#afe2c3fc2808e83353b7274dddd662c7e", null ]
    ] ],
    [ "lazy", "structboost_1_1hana_1_1lazy.html", [
      [ "eval", "structboost_1_1hana_1_1lazy.html#aae2998c08f1f80ed52a6acf57c4eec6c", null ],
      [ "make< lazy_tag >", "structboost_1_1hana_1_1lazy.html#aa968ecf473c93821f1726fd9692e97f3", null ],
      [ "make_lazy", "structboost_1_1hana_1_1lazy.html#a7dc86ca61b84fc42aabb525787ae61b4", null ],
      [ "operator|", "structboost_1_1hana_1_1lazy.html#a0527aedd89d16220a6b70404d4b1a322", null ]
    ] ],
    [ "map", "structboost_1_1hana_1_1map.html", [
      [ "make< map_tag >", "structboost_1_1hana_1_1map.html#a409d52de54cc7e55eca1a7b5dda4ce30", null ],
      [ "make_map", "structboost_1_1hana_1_1map.html#ae73cf43ee56352e4c25984b0fe3c3d04", null ],
      [ "to_map", "structboost_1_1hana_1_1map.html#a4feb32bd0a065a0732908716d4855b57", null ],
      [ "keys", "structboost_1_1hana_1_1map.html#a0f32260f859b2510dd16235b7bc011ac", null ],
      [ "values", "structboost_1_1hana_1_1map.html#a2e016a68e3ec6eb25868fadb7ce80132", null ],
      [ "insert", "structboost_1_1hana_1_1map.html#a5791e6dc0e27d8e3a113e4d94482550f", null ],
      [ "erase_key", "structboost_1_1hana_1_1map.html#af856f7bf77f69cdf1b8fd4e566eaef9b", null ],
      [ "union_", "structboost_1_1hana_1_1map.html#acd511f2c01f38405bfba0b6d5b2922e8", null ],
      [ "intersection", "structboost_1_1hana_1_1map.html#a3b3430482d4e88052e621f63a234f3eb", null ],
      [ "difference", "structboost_1_1hana_1_1map.html#a718ddfe86437adbbca1e1a5db651d139", null ],
      [ "symmetric_difference", "structboost_1_1hana_1_1map.html#a8bcb2455eb9f7074185d8fb61a99801e", null ],
      [ "operator==", "structboost_1_1hana_1_1map.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
      [ "operator!=", "structboost_1_1hana_1_1map.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
      [ "operator=", "structboost_1_1hana_1_1map.html#ae18123925b628b5cfcb1adaef5c83ac7", null ],
      [ "operator=", "structboost_1_1hana_1_1map.html#a9a6635ea36edc582518d278238defa0d", null ],
      [ "operator[]", "structboost_1_1hana_1_1map.html#a1532587d8da252c580d24c5f4ab66cca", null ],
      [ "map", "structboost_1_1hana_1_1map.html#a1ee432be0bd10f08a637a437e311e4e2", null ],
      [ "map", "structboost_1_1hana_1_1map.html#a943219d1c9692938167639d8ad2525b8", null ],
      [ "map", "structboost_1_1hana_1_1map.html#a675bb30af155b40f72cbe8607eefbe4e", null ],
      [ "map", "structboost_1_1hana_1_1map.html#a4a4f472e036abf9bcbda81e831f46e32", null ]
    ] ],
    [ "optional", "structboost_1_1hana_1_1optional.html", [
      [ "make< optional_tag >", "structboost_1_1hana_1_1optional.html#a76a84854b3051af000e698157d63a6a8", null ],
      [ "make_optional", "structboost_1_1hana_1_1optional.html#af1105a435d6435a2437cb5dc162ba463", null ],
      [ "just", "structboost_1_1hana_1_1optional.html#a8ad818d6df7379b0adefa45d2ac844d0", null ],
      [ "nothing", "structboost_1_1hana_1_1optional.html#a0c315287473aa87fe5ccd9d8a1c10186", null ],
      [ "maybe", "structboost_1_1hana_1_1optional.html#a6529e11cb228e99a05e81071752807d5", null ],
      [ "sfinae", "structboost_1_1hana_1_1optional.html#aa4c8c0b1ef3d8206974734b93646c9fd", null ],
      [ "is_just", "structboost_1_1hana_1_1optional.html#a1047a69893a62cd36eb0d2934f85e0e7", null ],
      [ "is_nothing", "structboost_1_1hana_1_1optional.html#a4eb266d123883c23853f7731a6c5953f", null ],
      [ "operator|", "structboost_1_1hana_1_1optional.html#af19873df9190014c0dd09781c210becc", null ],
      [ "operator==", "structboost_1_1hana_1_1optional.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
      [ "operator!=", "structboost_1_1hana_1_1optional.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
      [ "operator<", "structboost_1_1hana_1_1optional.html#aca31ad50b2d35d48aac88aa762530c75", null ],
      [ "operator>", "structboost_1_1hana_1_1optional.html#a65b9400772e651101ae83d7f9f7ba84d", null ],
      [ "operator<=", "structboost_1_1hana_1_1optional.html#a971bac762b767fe0ec222adb367c9aeb", null ],
      [ "operator>=", "structboost_1_1hana_1_1optional.html#adec95a8109b858673412671ba341611b", null ],
      [ "operator=", "structboost_1_1hana_1_1optional.html#abefc885243f38c66c52fdada3588f951", null ],
      [ "operator=", "structboost_1_1hana_1_1optional.html#a52057c5da4b9aee49ee15a167459fc9a", null ],
      [ "operator->", "structboost_1_1hana_1_1optional.html#a6eeef1512294d408857805eb3a790230", null ],
      [ "value", "structboost_1_1hana_1_1optional.html#acdcf71b43d4e27d5efbf0ad875d0be58", null ],
      [ "operator*", "structboost_1_1hana_1_1optional.html#a3132b919ab7710d79155674272961d4b", null ],
      [ "value_or", "structboost_1_1hana_1_1optional.html#ab65fe691bafd979111b52f97ec258e48", null ],
      [ "optional", "structboost_1_1hana_1_1optional.html#aefbd278cf7bb9e921707d6d827014bcb", null ],
      [ "optional", "structboost_1_1hana_1_1optional.html#a9074406adb54a6a848ba482895c51d1f", null ],
      [ "optional", "structboost_1_1hana_1_1optional.html#ac46a23f0ada20175c4c9a58af3d15753", null ],
      [ "optional", "structboost_1_1hana_1_1optional.html#a2b04ee87c0ac58621edf3ad5476a2949", null ],
      [ "optional", "structboost_1_1hana_1_1optional.html#adf824827b5d6f8c87d23b9526b9f35d2", null ]
    ] ],
    [ "pair", "structboost_1_1hana_1_1pair.html", [
      [ "make< pair_tag >", "structboost_1_1hana_1_1pair.html#aab78903e9982284e82744dec570afa8d", null ],
      [ "make_pair", "structboost_1_1hana_1_1pair.html#a1bc322b45af2148a413ba45ee8097045", null ],
      [ "operator==", "structboost_1_1hana_1_1pair.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
      [ "operator!=", "structboost_1_1hana_1_1pair.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
      [ "operator<", "structboost_1_1hana_1_1pair.html#aca31ad50b2d35d48aac88aa762530c75", null ],
      [ "operator>", "structboost_1_1hana_1_1pair.html#a65b9400772e651101ae83d7f9f7ba84d", null ],
      [ "operator<=", "structboost_1_1hana_1_1pair.html#a971bac762b767fe0ec222adb367c9aeb", null ],
      [ "operator>=", "structboost_1_1hana_1_1pair.html#adec95a8109b858673412671ba341611b", null ],
      [ "operator=", "structboost_1_1hana_1_1pair.html#a96ada4b84949f1653de497410af50013", null ],
      [ "operator=", "structboost_1_1hana_1_1pair.html#a3f1a25445fa5380a78bdf524b764e1c7", null ],
      [ "pair", "structboost_1_1hana_1_1pair.html#acb8494edc410c10d824e942341f30719", null ],
      [ "pair", "structboost_1_1hana_1_1pair.html#ad258681a711a7bf24d79e9d13a7a441e", null ],
      [ "pair", "structboost_1_1hana_1_1pair.html#aae31a284451c1c0486339c289a7887fe", null ],
      [ "pair", "structboost_1_1hana_1_1pair.html#ad295aada872521bce6e7775795b8318e", null ],
      [ "pair", "structboost_1_1hana_1_1pair.html#a962bff38110b5c39b1267fc88851198d", null ]
    ] ],
    [ "range", "structboost_1_1hana_1_1range.html", [
      [ "make< range_tag >", "structboost_1_1hana_1_1range.html#ad5ad9a1f847daa24ef62f5d81b8eef8e", null ],
      [ "make_range", "structboost_1_1hana_1_1range.html#aba8dd69deb1d810ef65ec289127bf0ab", null ],
      [ "range_c", "structboost_1_1hana_1_1range.html#a899b7a0c065ff64cd747fe1671753d3f", null ],
      [ "operator==", "structboost_1_1hana_1_1range.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
      [ "operator!=", "structboost_1_1hana_1_1range.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
      [ "operator[]", "structboost_1_1hana_1_1range.html#a766563b786c316320d175590fe3ad7af", null ]
    ] ],
    [ "set", "structboost_1_1hana_1_1set.html", [
      [ "make< set_tag >", "structboost_1_1hana_1_1set.html#aa337857e80b8a8c91880b0184aaf7534", null ],
      [ "make_set", "structboost_1_1hana_1_1set.html#af38c23fb98d8eec68c1491a8bca9ce43", null ],
      [ "insert", "structboost_1_1hana_1_1set.html#a5791e6dc0e27d8e3a113e4d94482550f", null ],
      [ "erase_key", "structboost_1_1hana_1_1set.html#af856f7bf77f69cdf1b8fd4e566eaef9b", null ],
      [ "union_", "structboost_1_1hana_1_1set.html#acd511f2c01f38405bfba0b6d5b2922e8", null ],
      [ "intersection", "structboost_1_1hana_1_1set.html#a3b3430482d4e88052e621f63a234f3eb", null ],
      [ "to_set", "structboost_1_1hana_1_1set.html#accbea694d32b341e860dac724c0c6933", null ],
      [ "difference", "structboost_1_1hana_1_1set.html#a718ddfe86437adbbca1e1a5db651d139", null ],
      [ "symmetric_difference", "structboost_1_1hana_1_1set.html#a8bcb2455eb9f7074185d8fb61a99801e", null ],
      [ "operator==", "structboost_1_1hana_1_1set.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
      [ "operator!=", "structboost_1_1hana_1_1set.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
      [ "operator[]", "structboost_1_1hana_1_1set.html#a426850019348f48aef6765c57061c631", null ],
      [ "set", "structboost_1_1hana_1_1set.html#a51bdb213a03abc126668c4c3b14fc50b", null ],
      [ "set", "structboost_1_1hana_1_1set.html#a937a7d47238690b571e7dd524278f6d5", null ],
      [ "set", "structboost_1_1hana_1_1set.html#ac5b7025edfb0c6c28f31d84598e130f0", null ]
    ] ],
    [ "string", "structboost_1_1hana_1_1string.html", [
      [ "make< string_tag >", "structboost_1_1hana_1_1string.html#a75de1ad7b14dc576a98d759dc3176ae9", null ],
      [ "make_string", "structboost_1_1hana_1_1string.html#acd99ab02697909eba5eb76caf1ca7a8b", null ],
      [ "to_string", "structboost_1_1hana_1_1string.html#aa3fb479070239c86673c624a21a845b6", null ],
      [ "string_c", "structboost_1_1hana_1_1string.html#a810915f5e494decfe47b047a3500c577", null ],
      [ "operator==", "structboost_1_1hana_1_1string.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
      [ "operator!=", "structboost_1_1hana_1_1string.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
      [ "operator<", "structboost_1_1hana_1_1string.html#aca31ad50b2d35d48aac88aa762530c75", null ],
      [ "operator>", "structboost_1_1hana_1_1string.html#a65b9400772e651101ae83d7f9f7ba84d", null ],
      [ "operator<=", "structboost_1_1hana_1_1string.html#a971bac762b767fe0ec222adb367c9aeb", null ],
      [ "operator>=", "structboost_1_1hana_1_1string.html#adec95a8109b858673412671ba341611b", null ],
      [ "operator+", "structboost_1_1hana_1_1string.html#a897cb2a15eeef6924a2b2fda36eac874", null ],
      [ "BOOST_HANA_STRING", "structboost_1_1hana_1_1string.html#a7f15faa77e126e1c2b08a2224ceefb84", null ],
      [ "operator\"\"_s", "structboost_1_1hana_1_1string.html#ad77f7afff008c2ce15739ad16a8bf0a8", null ],
      [ "operator[]", "structboost_1_1hana_1_1string.html#a186fd5a7d40373d568a0c3d4517da929", null ]
    ] ],
    [ "tuple", "structboost_1_1hana_1_1tuple.html", [
      [ "make< tuple_tag >", "structboost_1_1hana_1_1tuple.html#ad9d8c7efa77e573eba2dfc48b3343e66", null ],
      [ "make_tuple", "structboost_1_1hana_1_1tuple.html#af3c175cfb83276339f91e867d738a2e6", null ],
      [ "to_tuple", "structboost_1_1hana_1_1tuple.html#a749b564c8f115957837761d75191beac", null ],
      [ "tuple_t", "structboost_1_1hana_1_1tuple.html#a1997546daf58a48cc15498d338a03da3", null ],
      [ "tuple_c", "structboost_1_1hana_1_1tuple.html#a85c2f16caa2a1e12eefd1b3f69fa658e", null ],
      [ "operator|", "structboost_1_1hana_1_1tuple.html#a9f7ef8b098a26c3168e1dbd4dd54ff7b", null ],
      [ "operator==", "structboost_1_1hana_1_1tuple.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
      [ "operator!=", "structboost_1_1hana_1_1tuple.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
      [ "operator<", "structboost_1_1hana_1_1tuple.html#aca31ad50b2d35d48aac88aa762530c75", null ],
      [ "operator>", "structboost_1_1hana_1_1tuple.html#a65b9400772e651101ae83d7f9f7ba84d", null ],
      [ "operator<=", "structboost_1_1hana_1_1tuple.html#a971bac762b767fe0ec222adb367c9aeb", null ],
      [ "operator>=", "structboost_1_1hana_1_1tuple.html#adec95a8109b858673412671ba341611b", null ],
      [ "operator=", "structboost_1_1hana_1_1tuple.html#acddfa6d631c249ae667d52dd63c0aeaf", null ],
      [ "operator=", "structboost_1_1hana_1_1tuple.html#ad3f0fe520974a22cc12a978f4b061caa", null ],
      [ "operator[]", "structboost_1_1hana_1_1tuple.html#a8a7edb152340d0eabf67a62f9e25c99f", null ],
      [ "tuple", "structboost_1_1hana_1_1tuple.html#a8e10223983bfb3873c285be85f7ab273", null ],
      [ "tuple", "structboost_1_1hana_1_1tuple.html#a4e4e6193df38146b1eab93bcf963fc81", null ],
      [ "tuple", "structboost_1_1hana_1_1tuple.html#a9a5dd3930d94a900190de98247e0c415", null ],
      [ "tuple", "structboost_1_1hana_1_1tuple.html#a6cf99e86ab1506594eca03881748fe91", null ],
      [ "tuple", "structboost_1_1hana_1_1tuple.html#ac504757198d85ab9de1258de634e3b71", null ]
    ] ],
    [ "type", "structboost_1_1hana_1_1type.html", [
      [ "type_c", "structboost_1_1hana_1_1type.html#ae35139e732c4b75e91061513cf445628", null ],
      [ "decltype_", "structboost_1_1hana_1_1type.html#a7d68ff2275cbb295556d83598f04e39a", null ],
      [ "typeid_", "structboost_1_1hana_1_1type.html#a0ade557ac4240552c92bf47c7e04dfd4", null ],
      [ "make< type_tag >", "structboost_1_1hana_1_1type.html#a66f97c1903dcb6f227b29f3e35e68a56", null ],
      [ "make_type", "structboost_1_1hana_1_1type.html#a0c0e00c0ffe63703f3a04960d13c7b1c", null ],
      [ "sizeof_", "structboost_1_1hana_1_1type.html#a26b702b280ca02f118affaaca9112a8c", null ],
      [ "alignof_", "structboost_1_1hana_1_1type.html#a6fd9ac456f4b5574dcb16384dbb85736", null ],
      [ "is_valid", "structboost_1_1hana_1_1type.html#a2d2e7e08e284f7e0bd1bd9c3ad0e0a2b", null ],
      [ "operator==", "structboost_1_1hana_1_1type.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
      [ "operator!=", "structboost_1_1hana_1_1type.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
      [ "operator+", "structboost_1_1hana_1_1type.html#a228c1b24d16b2c765c816f816a09337c", null ]
    ] ]
];